import { ConversationsStyle } from "../Styles/ConversationsStyle";
import { ListItemStyle, BackdropStyle, ConfirmDialogStyle, AvatarStyle, BadgeStyle, DateStyle, ReceiptStyle } from "@cometchat/uikit-elements";
import { DatePatterns, SelectionMode, TitleAlignment } from "@cometchat/uikit-resources";
import { CometChatOption } from "@cometchat/uikit-resources";
import { CometChatTextFormatter } from "../Utils/CometChatFormatters/CometChatTextFormatter";
/**
 * @property {any} subtitleView - Property for subtitle view.
 * @property {any} options - Property for options.
 * @property {boolean} disableUsersPresence - Property to disable user's presence. Default is false.
 * @property {boolean} disableReadReceipt - Property to disable read receipt. Default is false.
 * @property {boolean} disableTyping - Property to disable typing. Default is false.
 * @property {string} deliveredIcon - Property for delivered icon. Default is "assets/message-delivered.svg".
 * @property {string} readIcon - Property for read icon. Default is "assets/message-read.svg".
 * @property {string} waitIcon - Property for wait icon. Default is "assets/wait.svg".
 * @property {string} errorIcon - Property for error icon. Default is "assets/warning-small.svg".
 * @property {DatePatterns} datePattern - Property for date pattern. Default is "DatePatterns.DayDateTime".
 * @property {ReceiptStyle} receiptStyle - Property for receipt style.
 * @property {string} sentIcon - Property for sent icon. Default is "assets/message-sent.svg".
 * @property {string} privateGroupIcon - Property for private group icon. Default is "assets/Private.svg".
 * @property {string} protectedGroupIcon - Property for protected group icon. Default is "assets/Locked.svg".
 * @property {string} passwordGroupIcon - Property for password-protected group icon. Default is undefined.
 * @property {string} customSoundForMessages - Property for custom sound for messages.
 * @property {CometChat.Conversation} activeConversation - Property for selected conversation. Default is null.
 * @property {string} searchIconURL - Property for search icon URL. Default is "assets/search.svg".
 * @property {boolean} hideSearch - Property to hide search. Default is true.
 * @property {CometChat.ConversationsRequestBuilder} conversationsRequestBuilder - Property for conversation request builder. Default is "new CometChat.ConversationsRequestBuilder().setLimit(30)".
 * @property {any} emptyStateView - Property for empty state view.
 * @property {member:CometChat.Conversation} onSelect - Property for on select.
 * @property {string} loadingIconURL - Property for loading icon URL. Default is "assets/Spinner.svg".
 * @property {any} errorStateView - Property for error state view.
 * @property {any} loadingStateView - Property for loading state view.
 * @property {TitleAlignment} titleAlignment - Property for title alignment. Default is "TitleAlignment.left".
 * @property {any} listItemView - Property for list item view.
 * @property {any} menu - Property for menu.
 * @property {boolean} hideSeparator - Property to hide separator. Default is false.
 * @property {boolean} hideError - Property to hide error. Default is false.
 * @property {SelectionMode} selectionMode - Property for selection mode. Default is "SelectionMode.none".
 * @property {boolean} disableSoundForMessages - Property to disable sound
 * @property {ConfirmDialogStyle} deleteConversationDialogStyle - The style of the dialog that appears when user tries to delete a conversation.
 * @property {BadgeStyle} badgeStyle - The style of the badge that appears on the conversation list items.
 * @property {DateStyle} dateStyle - The style of the date that appears in the conversation list items.
 * @property {ConversationsStyle} conversationsStyle - The style of the conversation list.
 * @property {ListItemStyle} listItemStyle - The style of the conversation list item.
 * @property {BaseStyle} statusIndicatorStyle - The style of the status indicator that appears in the conversation list items.
 * @property {AvatarStyle} avatarStyle - The style of the avatar that appears in the conversation list items.
 * @property {boolean} disableMentions - Disable Mentions in message list
 * @property {CometChatTextFormatter[]} textFormatters - List of Text Formatter Instances
 * @property {boolean} hideReceipt - Property to hide receipt. Default is false.
 */
export declare class ConversationsConfiguration {
    subtitleView: any;
    options: ((member: CometChat.Conversation) => CometChatOption[]) | null;
    disableUsersPresence: boolean;
    /**
     * @deprecated
     *
     * This property is deprecated as of version 4.3.17 due to newer property 'hideReceipt'. It will be removed in subsequent versions.
     */
    disableReceipt: boolean;
    hideReceipt: boolean;
    disableTyping: boolean;
    deliveredIcon: string;
    readIcon: string;
    waitIcon: string;
    errorIcon: string;
    datePattern: DatePatterns;
    receiptStyle: ReceiptStyle;
    sentIcon: string;
    privateGroupIcon: string;
    /**
   * @deprecated
   *
   * This property is deprecated as of version 4.3.9 due to newer property 'passwordGroupIcon'. It will be removed in subsequent versions.
   */
    protectedGroupIcon: string;
    passwordGroupIcon: string | undefined;
    customSoundForMessages: string;
    onError: ((error: CometChat.CometChatException) => void) | null;
    onItemClick: ((conversation: CometChat.Conversation) => void) | null;
    conversationsRequestBuilder: CometChat.ConversationsRequestBuilder;
    emptyStateView: any;
    onSelect: (conversation: CometChat.Conversation, selected: boolean) => void;
    loadingIconURL: string;
    errorStateView: any;
    loadingStateView: any;
    titleAlignment: TitleAlignment;
    listItemView: any;
    menu: any;
    hideSeparator: boolean;
    hideError: boolean;
    selectionMode: SelectionMode;
    disableSoundForMessages: boolean;
    deleteConversationDialogStyle: ConfirmDialogStyle;
    badgeStyle: BadgeStyle;
    dateStyle: DateStyle;
    conversationsStyle: ConversationsStyle;
    listItemStyle: ListItemStyle;
    statusIndicatorStyle: any;
    avatarStyle: AvatarStyle;
    backdropStyle: BackdropStyle;
    disableMentions: boolean;
    textFormatters: CometChatTextFormatter[];
    constructor(props: Partial<ConversationsConfiguration>);
}
//# sourceMappingURL=ConversationsConfiguration.d.ts.map