import { CometChatDetailsTemplate } from "@cometchat/uikit-resources";
import { AvatarStyle, BackdropStyle, ListItemStyle, ConfirmDialogStyle } from "@cometchat/uikit-elements";
import { DetailsStyle } from "../Styles/DetailsStyle";
import { AddMembersConfiguration } from "./AddMembersConfiguration";
import { GroupMembersConfiguration } from "./GroupMembersConfiguration";
import { BannedMembersConfiguration } from "./BannedMembersConfiguration";
import { TransferOwnershipConfiguration } from "./TransferOwnershipConfiguration";
/**

* DetailsConfiguration class represents the configuration options for the details view.
* @property  {closeButtonIconURL} - string: The URL of the icon used for the close button.
* @property {hideProfile} - boolean: If true, the profile of the user/group will be hidden.
* @property {subtitleView} - any: The subtitle view to be displayed in the details view.
* @property {customProfileView} - any: The custom profile view to be displayed in the details view.
* @property {data} - CometChatDetailsTemplate[]: The array of CometChatDetailsTemplate objects to be displayed in the details view.
* @property {disableUsersPresence} - boolean: If true, the presence of users will be disabled in the details view.
* @property {privateGroupIcon} - string: The URL of the icon used for the private group.
* @property {protectedGroupIcon} - string: The URL of the icon used for the protected group.
* @property {passwordGroupIcon} - string: The URL of the icon used for the password-protected group.
* @property {onError} - (error: any) => void: The callback function that will be called when an error occurs.
* @property {onClose} - () => void: The callback function that will be called when the details view is closed.
* @property {leaveDialogStyle} - ConfirmDialogStyle: The style configuration options for the leave dialog.
* @property {statusIndicatorStyle} - any: The style configuration options for the status indicator.
* @property {avatarStyle} - AvatarStyle: The style configuration options for the avatar.
* @property {detailsStyle} - DetailsStyle: The style configuration options for the details view.
* @property {listItemStyle} - ListItemStyle: The style configuration options for the list items in the details view.
*/
export declare class DetailsConfiguration {
    closeButtonIconURL: string;
    hideProfile: boolean;
    subtitleView: any;
    customProfileView: any;
    data?: (user?: CometChat.User, group?: CometChat.Group) => CometChatDetailsTemplate[];
    disableUsersPresence: boolean;
    privateGroupIcon: string;
    /**
     * @deprecated
     *
     * This property is deprecated as of version 4.3.9 due to newer property 'passwordGroupIcon'. It will be removed in subsequent versions.
     */
    protectedGroupIcon: string;
    passwordGroupIcon: string | undefined;
    addMembersConfiguration: AddMembersConfiguration;
    groupMembersConfiguration: GroupMembersConfiguration;
    bannedMembersConfiguration: BannedMembersConfiguration;
    transferOwnershipConfiguration: TransferOwnershipConfiguration;
    backdropStyle: BackdropStyle;
    onError: (error: any) => void;
    onClose: () => void;
    leaveDialogStyle: ConfirmDialogStyle;
    statusIndicatorStyle: any;
    detailsStyle: DetailsStyle;
    avatarStyle: AvatarStyle;
    listItemStyle: ListItemStyle;
    constructor(props: Partial<DetailsConfiguration>);
}
//# sourceMappingURL=DetailsConfiguration.d.ts.map