import { ActionSheetStyle, BackdropStyle, MediaRecorderStyle } from "@cometchat/uikit-elements";
import { AIOptionsStyle } from "../AI";
import { AuxiliaryButtonAlignment, PreviewMessageMode } from "@cometchat/uikit-resources";
import { CometChatMessageComposerAction } from "@cometchat/uikit-resources";
import { CometChatTextFormatter } from "../Utils/CometChatFormatters/CometChatTextFormatter";
import { MessageComposerStyle } from "../Styles/MessageComposerStyle";
import { UserMemberWrapperConfiguration } from "./UserMemberWrapperConfiguration";
/**
 * Class representing the configuration options for the message composer.
 *
 * @property {string} text - The initial text for the message composer. Default is an empty string.
 * @property {any} headerView - The view for the header of the message composer.
 * @property {any} onTextChange - The callback function for when the text in the message composer changes.
 * @property {string} attachmentIconURL - The URL of the attachment icon. Default is "assets/Plus.svg".
 * @property {CometChatMessageComposerAction[]} attachmentOptions - The attachment options for the message composer.
 * @property {any} secondaryButtonView - The view for the secondary button of the message composer.
 * @property {any} auxilaryButtonView - The view for the auxiliary button of the message composer.
 * @property {AuxiliaryButtonAlignment} auxiliaryButtonsAlignment - The alignment of the auxiliary buttons. Default is AuxiliaryButtonAlignment.right.
 * @property {any} sendButtonView - The view for the send button of the message composer.
 * @property {boolean} hideLiveReaction - Flag to hide live reaction. Default is false.
 * @property {string} LiveReactionIconURL - The URL of the live reaction icon. Default is "assets/heart-reaction.png".
 * @property {object} messageComposerStyle - The style for the message composer.
 * @property {message: CometChat.BaseMessage, previewMessageMode:PreviewMessageMode} onSendButtonClick - The callback function for when the send button is clicked.
 * @property {any} onError - The callback function for when an error occurs.
 * @property {CometChatTextFormatter[]} textFormatters - List of Text Formatter Instances
 * @property {boolean} disableMentions - Disable Mentions in message list
 * @property {string} mentionsWarningText - Warning Text to be showed when mentions limit is reached
 * @property {any} mentionsWarningStyle - Style For Warning Message showed when mentions limit is reached
 * @property {BackdropStyle} backdropStyle - Style for backdrop component. This property is only for the Angular UI Kit.
 */
declare class MessageComposerConfiguration {
    text: string;
    headerView: any;
    onTextChange: any;
    attachmentIconURL: string;
    attachmentOptions: ((item: CometChat.User | CometChat.Group, composerId: ComposerId) => CometChatMessageComposerAction[]) | undefined;
    secondaryButtonView: any;
    auxilaryButtonView: any;
    auxiliaryButtonsAlignment: AuxiliaryButtonAlignment;
    sendButtonIconURL: string;
    sendButtonView: any;
    emojiIconURL: string;
    AIIconURL: string;
    hideLayoutMode: boolean;
    hideLiveReaction: boolean;
    LiveReactionIconURL: string;
    messageComposerStyle: MessageComposerStyle;
    onSendButtonClick: ((message: CometChat.BaseMessage, previewMessageMode?: PreviewMessageMode) => void) | undefined;
    onError: ((error: CometChat.CometChatException) => void) | null;
    actionSheetStyle: ActionSheetStyle;
    AIOptionsStyle: AIOptionsStyle;
    backdropStyle: BackdropStyle;
    hideVoiceRecording: boolean;
    mediaRecorderStyle: MediaRecorderStyle;
    voiceRecordingCloseIconURL: string;
    voiceRecordingStartIconURL: string;
    voiceRecordingStopIconURL: string;
    voiceRecordingSubmitIconURL: string;
    voiceRecordingIconURL: string;
    userMemberWrapperConfiguration: UserMemberWrapperConfiguration;
    textFormatters: CometChatTextFormatter[];
    disableMentions: boolean;
    mentionsWarningText: string;
    mentionsWarningStyle: any;
    constructor(props: Partial<MessageComposerConfiguration>);
}
export type ComposerId = {
    parentMessageId: number | null;
    user: string | null;
    group: string | null;
};
export { MessageComposerConfiguration };
//# sourceMappingURL=MessageComposerConfiguration.d.ts.map