import { AvatarStyle, BackdropStyle, DateStyle, EmojiKeyboardStyle } from "@cometchat/uikit-elements";
import { DatePatterns, MessageListAlignment } from "@cometchat/uikit-resources";
import { CometChatMessageTemplate } from "@cometchat/uikit-resources";
import { MessageInformationConfiguration } from "./MessageInformationConfiguration";
import { MessageListStyle } from '../Styles/MessageListStyle';
import { ReactionsConfiguration } from './ReactionsConfiguration';
import { TimestampAlignment } from "@cometchat/uikit-resources";
import { CometChatTextFormatter } from "../Utils/CometChatFormatters/CometChatTextFormatter";
/**
 * @property {any} emptyStateView - The view to be displayed in case there are no messages.
 * @property {any} errorStateView - The view to be displayed in case of error.
 * @property {any} loadingStateView - The view to be displayed when messages are being fetched.
 * @property {boolean} disableReadReceipt - The flag to enable/disable read receipts.
 * @property {string} readIcon - The icon to be displayed as read receipt.
 * @property {string} deliveredIcon - The icon to be displayed as delivered receipt.
 * @property {string} sentIcon - The icon to be displayed as sent receipt.
 * @property {string} waitIcon - The icon to be displayed as wait receipt.
 * @property {string} errorIcon - The icon to be displayed as error receipt.
 * @property {string} alignment - The alignment of the messages (standard, reverse).
 * @property {boolean} showAvatar - The flag to enable/disable showing avatars.
 * @property {boolean} hideError - The flag to enable/disable showing error.
 * @property {DatePatterns} datePattern - The date pattern for the messages.
 * @property {TimestampAlignment} timestampAlignment - The alignment of the timestamps (top, bottom).
 * @property {DatePatterns} DateSeparatorPattern - The date pattern for the date separators.
 * @property {CometChatMessageTemplate[]} templates - The types of messages to be displayed.
 * @property {any} messagesRequestBuilder - The builder to fetch messages.
 * @property {number} thresholdValue - The threshold value to fetch messages.
 * @property {any} onThreadRepliesClick - The function to be called when thread replies are clicked.
 * @property {any} headerView - The header view to be displayed above the messages.
 * @property {any} footerView - The footer view to be displayed below the messages.
 * @property {BaseStyle} wrapperMessageBubbleStyle - The style for the message bubble.
 * @property {AvatarStyle} avatarStyle - The style for the avatar.
 * @property {DateStyle} dateSeparatorStyle - The style for the date separator.
 * @property {MessageListStyle} messageListStyle - The style for the message list.
 * @property {any} onError - The function to be called in case of error.
 * @property {CometChatTextFormatter[]} textFormatters - List of Text Formatter Instances
 * @property {boolean} disableMentions - Disable Mentions in message list
 * @property {boolean} hideReceipt - Property to hide receipt. Default is false.
 */
declare class MessageListConfiguration {
    emptyStateView: any;
    errorStateView: any;
    loadingStateView: any;
    /**
     * @deprecated
     *
     * This property is deprecated as of version 4.3.17 due to newer property 'hideReceipt'. It will be removed in subsequent versions.
     */
    disableReceipt: boolean;
    hideReceipt: boolean;
    readIcon: string;
    deliveredIcon: string;
    sentIcon: string;
    waitIcon: string;
    errorIcon: string;
    alignment: MessageListAlignment;
    showAvatar: boolean;
    datePattern: DatePatterns;
    timestampAlignment: TimestampAlignment;
    DateSeparatorPattern: DatePatterns;
    hideDateSeparator: boolean;
    templates: CometChatMessageTemplate[];
    hideError: boolean;
    messagesRequestBuilder: CometChat.MessagesRequestBuilder;
    messageInformationConfiguration: MessageInformationConfiguration;
    thresholdValue: number;
    scrollToBottomOnNewMessages: boolean;
    onThreadRepliesClick: any;
    headerView: any;
    footerView: any;
    loadingIconURL: string;
    avatarStyle: AvatarStyle;
    dateSeparatorStyle: DateStyle;
    messageListStyle: MessageListStyle;
    onError: ((error: CometChat.CometChatException) => void) | null;
    backdropStyle: BackdropStyle;
    disableMentions: boolean;
    reactionsConfiguration: ReactionsConfiguration;
    disableReactions: boolean;
    emojiKeyboardStyle: EmojiKeyboardStyle;
    threadIndicatorIcon: string;
    textFormatters: CometChatTextFormatter[];
    constructor(props: Partial<MessageListConfiguration>);
}
export { MessageListConfiguration };
//# sourceMappingURL=MessageListConfiguration.d.ts.map